@@ -25,10 +25,10 @@ use {
         native_token::lamports_to_sol,
         pubkey::Pubkey,
         signature::Signature,
+        stake::state::{Authorized, Lockup},
         stake_history::StakeHistoryEntry,
         transaction::{Transaction, TransactionError},
     },
-    solana_stake_program::stake_state::{Authorized, Lockup},
     solana_transaction_status::{
         EncodedConfirmedBlock, EncodedTransaction, TransactionConfirmationStatus,
         UiTransactionStatusMeta,
@@ -233,10 +233,6 @@ pub struct CliEpochInfo {
     pub epoch_info: EpochInfo,
     #[serde(skip)]
     pub average_slot_time_ms: u64,
-    #[serde(skip)]
-    pub start_block_time: Option<UnixTimestamp>,
-    #[serde(skip)]
-    pub current_block_time: Option<UnixTimestamp>,
 }
 
 impl QuietDisplay for CliEpochInfo {}
@@ -281,41 +277,21 @@ impl fmt::Display for CliEpochInfo {
                 remaining_slots_in_epoch
             ),
         )?;
-        let (time_elapsed, annotation) = if let (Some(start_block_time), Some(current_block_time)) =
-            (self.start_block_time, self.current_block_time)
-        {
-            (
-                Duration::from_secs((current_block_time - start_block_time) as u64),
-                None,
-            )
-        } else {
-            (
-                slot_to_duration(self.epoch_info.slot_index, self.average_slot_time_ms),
-                Some("* estimated based on current slot durations"),
-            )
-        };
-        let time_remaining = slot_to_duration(remaining_slots_in_epoch, self.average_slot_time_ms);
         writeln_name_value(
             f,
             "Epoch Completed Time:",
             &format!(
-                "{}{}/{} ({} remaining)",
-                humantime::format_duration(time_elapsed).to_string(),
-                if annotation.is_some() { "*" } else { "" },
-                humantime::format_duration(time_elapsed + time_remaining).to_string(),
-                humantime::format_duration(time_remaining).to_string(),
+                "{}/{} ({} remaining)",
+                slot_to_human_time(self.epoch_info.slot_index, self.average_slot_time_ms),
+                slot_to_human_time(self.epoch_info.slots_in_epoch, self.average_slot_time_ms),
+                slot_to_human_time(remaining_slots_in_epoch, self.average_slot_time_ms)
             ),
-        )?;
-        if let Some(annotation) = annotation {
-            writeln!(f)?;
-            writeln!(f, "{}", annotation)?;
-        }
-        Ok(())
+        )
     }
 }
 
-fn slot_to_duration(slot: Slot, slot_time_ms: u64) -> Duration {
-    Duration::from_secs((slot * slot_time_ms) / 1000)
+fn slot_to_human_time(slot: Slot, slot_time_ms: u64) -> String {
+    humantime::format_duration(Duration::from_secs((slot * slot_time_ms) / 1000)).to_string()
 }
 
 #[derive(Serialize, Deserialize, Default)]
@@ -347,8 +323,6 @@ pub struct CliValidators {
     pub total_current_stake: u64,
     pub total_delinquent_stake: u64,
     pub validators: Vec<CliValidator>,
-    pub average_skip_rate: f64,
-    pub average_stake_weighted_skip_rate: f64,
     #[serde(skip_serializing)]
     pub validators_sort_order: CliValidatorsSortOrder,
     #[serde(skip_serializing)]
@@ -512,18 +486,6 @@ impl fmt::Display for CliValidators {
             writeln!(f, "{}", header)?;
         }
 
-        writeln!(f)?;
-        writeln_name_value(
-            f,
-            "Average Stake-Weighted Skip Rate:",
-            &format!("{:.2}%", self.average_stake_weighted_skip_rate,),
-        )?;
-        writeln_name_value(
-            f,
-            "Average Unweighted Skip Rate:    ",
-            &format!("{:.2}%", self.average_skip_rate),
-        )?;
-
         writeln!(f)?;
         writeln_name_value(
             f,
@@ -771,7 +733,6 @@ pub struct CliEpochReward {
     pub post_balance: u64, // lamports
     pub percent_change: f64,
     pub apr: Option<f64>,
-    pub commission: Option<u8>,
 }
 
 #[derive(Serialize, Deserialize)]
@@ -816,27 +777,23 @@ impl fmt::Display for CliKeyedEpochRewards {
         writeln!(f, "Epoch Rewards:")?;
         writeln!(
             f,
-            "  {:<44}  {:<18}  {:<18}  {:>14}  {:>14}  {:>10}",
-            "Address", "Amount", "New Balance", "Percent Change", "APR", "Commission"
+            "  {:<44}  {:<18}  {:<18}  {:>14}  {:>14}",
+            "Address", "Amount", "New Balance", "Percent Change", "APR"
         )?;
         for keyed_reward in &self.rewards {
             match &keyed_reward.reward {
                 Some(reward) => {
                     writeln!(
                         f,
-                        "  {:<44}  ◎{:<17.9}  ◎{:<17.9}  {:>13.9}%  {:>14}  {:>10}",
+                        "  {:<44}  ◎{:<17.9}  ◎{:<17.9}  {:>13.2}%  {}",
                         keyed_reward.address,
                         lamports_to_sol(reward.amount),
                         lamports_to_sol(reward.post_balance),
                         reward.percent_change,
                         reward
                             .apr
-                            .map(|apr| format!("{:.2}%", apr))
+                            .map(|apr| format!("{:>13.2}%", apr))
                             .unwrap_or_default(),
-                        reward
-                            .commission
-                            .map(|commission| format!("{}%", commission))
-                            .unwrap_or_else(|| "-".to_string())
                     )?;
                 }
                 None => {
@@ -953,13 +910,13 @@ fn show_epoch_rewards(
         writeln!(f, "Epoch Rewards:")?;
         writeln!(
             f,
-            "  {:<6}  {:<11}  {:<18}  {:<18}  {:>14}  {:>14}  {:>10}",
-            "Epoch", "Reward Slot", "Amount", "New Balance", "Percent Change", "APR", "Commission"
+            "  {:<6}  {:<11}  {:<18}  {:<18}  {:>14}  {:>14}",
+            "Epoch", "Reward Slot", "Amount", "New Balance", "Percent Change", "APR"
         )?;
         for reward in epoch_rewards {
             writeln!(
                 f,
-                "  {:<6}  {:<11}  ◎{:<17.9}  ◎{:<17.9}  {:>13.9}%  {:>14}  {:>10}",
+                "  {:<6}  {:<11}  ◎{:<17.9}  ◎{:<17.9}  {:>13.2}%  {}",
                 reward.epoch,
                 reward.effective_slot,
                 lamports_to_sol(reward.amount),
@@ -967,12 +924,8 @@ fn show_epoch_rewards(
                 reward.percent_change,
                 reward
                     .apr
-                    .map(|apr| format!("{:.2}%", apr))
+                    .map(|apr| format!("{:>13.2}%", apr))
                     .unwrap_or_default(),
-                reward
-                    .commission
-                    .map(|commission| format!("{}%", commission))
-                    .unwrap_or_else(|| "-".to_string())
             )?;
         }
     }
@@ -1716,7 +1669,6 @@ pub struct CliFeesInner {
     pub blockhash: String,
     pub lamports_per_signature: u64,
     pub last_valid_slot: Option<Slot>,
-    pub last_valid_block_height: Option<Slot>,
 }
 
 impl QuietDisplay for CliFeesInner {}
@@ -1730,11 +1682,11 @@ impl fmt::Display for CliFeesInner {
             "Lamports per signature:",
             &self.lamports_per_signature.to_string(),
         )?;
-        let last_valid_block_height = self
-            .last_valid_block_height
+        let last_valid_slot = self
+            .last_valid_slot
             .map(|s| s.to_string())
             .unwrap_or_default();
-        writeln_name_value(f, "Last valid block height:", &last_valid_block_height)
+        writeln_name_value(f, "Last valid slot:", &last_valid_slot)
     }
 }
 
@@ -1763,7 +1715,6 @@ impl CliFees {
         blockhash: Hash,
         lamports_per_signature: u64,
         last_valid_slot: Option<Slot>,
-        last_valid_block_height: Option<Slot>,
     ) -> Self {
         Self {
             inner: Some(CliFeesInner {
@@ -1771,7 +1722,6 @@ impl CliFees {
                 blockhash: blockhash.to_string(),
                 lamports_per_signature,
                 last_valid_slot,
-                last_valid_block_height,
             }),
         }
     }
@@ -2186,8 +2136,8 @@ impl fmt::Display for CliBlock {
             writeln!(f, "Rewards:")?;
             writeln!(
                 f,
-                "  {:<44}  {:^15}  {:<15}  {:<20}  {:>14}  {:>10}",
-                "Address", "Type", "Amount", "New Balance", "Percent Change", "Commission"
+                "  {:<44}  {:^15}  {:<15}  {:<20}  {:>14}",
+                "Address", "Type", "Amount", "New Balance", "Percent Change"
             )?;
             for reward in rewards {
                 let sign = if reward.lamports < 0 { "-" } else { "" };
@@ -2195,7 +2145,7 @@ impl fmt::Display for CliBlock {
                 total_rewards += reward.lamports;
                 writeln!(
                     f,
-                    "  {:<44}  {:^15}  {:>15}  {}  {}",
+                    "  {:<44}  {:^15}  {:>15}  {}",
                     reward.pubkey,
                     if let Some(reward_type) = reward.reward_type {
                         format!("{}", reward_type)
@@ -2217,11 +2167,7 @@ impl fmt::Display for CliBlock {
                                 / (reward.post_balance as f64 - reward.lamports as f64))
                                 * 100.0
                         )
-                    },
-                    reward
-                        .commission
-                        .map(|commission| format!("{:>9}%", commission))
-                        .unwrap_or_else(|| "    -".to_string())
+                    }
                 )?;
             }
 
@@ -2462,10 +2408,6 @@ mod tests {
             fn try_sign_message(&self, _message: &[u8]) -> Result<Signature, SignerError> {
                 Ok(Signature::new(&[1u8; 64]))
             }
-
-            fn is_interactive(&self) -> bool {
-                false
-            }
         }
 
         let present: Box<dyn Signer> = Box::new(keypair_from_seed(&[2u8; 32]).unwrap());
